<?php

namespace InspireLabs\WooInpost;

use Exception;
use InspireLabs\WooInpost\shipping\EasyPack_Shipping_Method_Courier;
use InspireLabs\WooInpost\shipping\EasyPack_Shipping_Method_Courier_C2C;
use InspireLabs\WooInpost\shipping\EasyPack_Shipping_Method_Courier_COD;
use InspireLabs\WooInpost\shipping\EasyPack_Shipping_Method_Courier_Local_Express;
use InspireLabs\WooInpost\shipping\EasyPack_Shipping_Method_Courier_Local_Express_COD;
use InspireLabs\WooInpost\shipping\EasyPack_Shipping_Method_Courier_Local_Standard;
use InspireLabs\WooInpost\shipping\EasyPack_Shipping_Method_Courier_Local_Standard_COD;
use InspireLabs\WooInpost\shipping\EasyPack_Shipping_Method_Courier_LSE;
use InspireLabs\WooInpost\shipping\EasyPack_Shipping_Method_Courier_LSE_COD;
use InspireLabs\WooInpost\shipping\EasyPack_Shipping_Method_Courier_Palette;
use InspireLabs\WooInpost\shipping\EasyPack_Shipping_Method_Courier_Palette_COD;
use InspireLabs\WooInpost\shipping\EasyPack_Shippng_Parcel_Machines;
use InspireLabs\WooInpost\shipping\EasyPack_Shippng_Parcel_Machines_COD;

/**
 * EasyPack AJAX
 *
 * @author      WPDesk
 * @category    Admin
 * @package     EasyPack
 * @version     2.1.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( ! class_exists( 'EasyPack_AJAX' ) ) :

	class EasyPack_AJAX {

		/**
		 * Ajax handler
		 */
		public static function init() {
			add_action( 'wp_ajax_easypack',
				array( __CLASS__, 'ajax_easypack' ) );
			add_action( 'admin_head',
				array( __CLASS__, 'wp_footer_easypack_nonce' ) );
		}

		public static function wp_footer_easypack_nonce() {
			?>
            <script type="text/javascript">
                var easypack_nonce = '<?php echo wp_create_nonce( 'easypack_nonce' ); ?>';
            </script>
			<?php
		}

		public static function ajax_easypack() {
			check_ajax_referer( 'easypack_nonce', 'security' );

			if ( isset( $_POST['easypack_action'] ) ) {
				$action = $_POST['easypack_action'];
				if ( $action == 'returns_page_create' ) {
					self::create_returns_page();
				}
				if ( $action == 'dispatch_point' ) {
					self::dispatch_point();
				}
				if ( $action == 'parcel_machines_create_package' ) {
					self::parcel_machines_create_package();
				}
				if ( $action == 'parcel_machines_cancel_package' ) {
					self::parcel_machines_cancel_package();
				}
				if ( $action == 'parcel_machines_get_stickers' ) {
					self::parcel_machines_get_stickers();
				}
				if ( $action == 'parcel_machines_cod_get_payment_status' ) {
					self::parcel_machines_cod_get_payment_status();
				}
				if ( $action == 'parcel_machines_cod_create_package' ) {
					self::parcel_machines_cod_create_package();
				}
				if ( $action == 'courier_create_package' ) {
					self::courier_create_package();
				}
				if ( $action == 'courier_c2c_create_package' ) {
					self::courier_c2c_create_package();
				}
				if ( $action == 'courier_lse_create_package' ) {
					self::courier_lse_create_package();
				}
				if ( $action == 'courier_lse_create_package_cod' ) {
					self::courier_lse_create_package_cod();
				}
				if ( $action == 'courier_local_standard_create_package' ) {
					self::courier_local_standard_create_package();
				}
				if ( $action == 'courier_local_standard_cod_create_package' ) {
					self::courier_local_standard_cod_create_package();
				}
				if ( $action == 'courier_local_express_create_package' ) {
					self::courier_local_express_create_package();
				}
				if ( $action == 'courier_local_express_cod_create_package' ) {
					self::courier_local_express_cod_create_package();
				}
				if ( $action == 'courier_palette_create_package' ) {
					self::courier_palette_create_package();
				}
				if ( $action == 'courier_palette_cod_create_package' ) {
					self::courier_palette_cod_create_package();
				}
				if ( $action == 'courier_cod_create_package' ) {
					self::courier_cod_create_package();
				}
				if ( $action == 'parcel_machines_cod_cancel_package' ) {
					self::parcel_machines_cod_cancel_package();
				}
				if ( $action == 'crossborder_parcel_machines_create_package' ) {
					self::crossborder_parcel_machines_create_package();
				}
				if ( $action == 'crossborder_parcel_machines_processing' ) {
					self::crossborder_parcel_machines_processing();
				}
				if ( $action == 'crossborder_courier_create_package' ) {
					self::crossborder_courier_create_package();
				}
				if ( $action == 'crossborder_courier_processing' ) {
					self::crossborder_courier_processing();
				}
				if ( $action == 'easypack_dispatch_order' ) {
					self::easypack_dispatch_order();
				}
				if ( $action == 'easypack_create_stickers' ) {
					self::create_stickers();
				}
				if ( $action == 'easypack_calculate_shipment_cost' ) {
					EasyPack::EasyPack()
					        ->get_shipment_price_calculator_service()
					        ->calculate_shipment_cost_ajax();
				}
			}
		}

		public static function dispatch_point() {
			$dispatch_point_name = $_POST['dispatch_point_name'];
			try {
				$dispatch_point
					= EasyPack_API()->dispatch_point( $dispatch_point_name );
				echo json_encode( $dispatch_point );
			} catch ( Exception $e ) {
				echo 0;
			}
			wp_die();
		}

		public static function parcel_machines_create_package() {
			EasyPack_Shippng_Parcel_Machines::ajax_create_package();
		}

		public static function parcel_machines_cancel_package() {
			EasyPack_Shippng_Parcel_Machines::ajax_cancel_package();
		}

		public static function parcel_machines_get_stickers() {
			EasyPack_Shippng_Parcel_Machines::ajax_parcel_machines_get_stickers();
		}

		public static function parcel_machines_cod_get_payment_status() {
			EasyPack_Shippng_Parcel_Machines_COD::ajax_get_payment_status();
		}

		public static function parcel_machines_cod_create_package() {
			EasyPack_Shippng_Parcel_Machines_COD::ajax_create_package();
		}

		/**
		 * @throws \ReflectionException
		 */
		public static function courier_create_package() {
			EasyPack_Shipping_Method_Courier::ajax_create_package();
		}

		/**
		 * @throws \ReflectionException
		 */
		public static function courier_c2c_create_package() {
			EasyPack_Shipping_Method_Courier_C2C::ajax_create_package();
		}

		/**
		 * @throws \ReflectionException
		 */
		public static function courier_lse_create_package() {
			EasyPack_Shipping_Method_Courier_LSE::ajax_create_package();
		}

		/**
		 * @throws \ReflectionException
		 */
		public static function courier_lse_create_package_cod() {
			EasyPack_Shipping_Method_Courier_LSE_COD::ajax_create_package();
		}

		/**
		 * @throws \ReflectionException
		 */
		public static function courier_local_standard_create_package() {
			EasyPack_Shipping_Method_Courier_Local_Standard::ajax_create_package();
		}

		/**
		 * @throws \ReflectionException
		 */
		public static function courier_local_standard_cod_create_package() {
			EasyPack_Shipping_Method_Courier_Local_Standard_COD::ajax_create_package();
		}

		/**
		 * @throws \ReflectionException
		 */
		public static function courier_local_express_create_package() {
			EasyPack_Shipping_Method_Courier_Local_Express::ajax_create_package();
		}

		public static function courier_local_express_cod_create_package() {
			EasyPack_Shipping_Method_Courier_Local_Express_COD::ajax_create_package();
		}

		/**
		 * @throws \ReflectionException
		 */
		public static function courier_palette_create_package() {
			EasyPack_Shipping_Method_Courier_Palette::ajax_create_package();
		}

		/**
		 * @throws \ReflectionException
		 */
		public static function courier_palette_cod_create_package() {
			EasyPack_Shipping_Method_Courier_Palette_COD::ajax_create_package();
		}

		/**
		 * @throws \ReflectionException
		 */
		public static function courier_cod_create_package() {
			EasyPack_Shipping_Method_Courier_COD::ajax_create_package();
		}

		public static function parcel_machines_cod_cancel_package() {
			EasyPack_Shippng_Parcel_Machines_COD::ajax_cancel_package();
		}

		public static function crossborder_parcel_machines_create_package() {
			//EasyPack_Shippng_Cross_Border_Parcel_Machines::ajax_create_package();
		}

		public static function crossborder_parcel_machines_processing() {
			//EasyPack_Shippng_Cross_Border_Parcel_Machines::ajax_processing();
		}

		public static function crossborder_courier_create_package() {
			//EasyPack_Shippng_Cross_Border_Courier::ajax_create_package();
		}

		public static function crossborder_courier_processing() {
			//EasyPack_Shippng_Cross_Border_Courier::ajax_processing();
		}

		public static function easypack_dispatch_order() {
			EasyPack_Shippng_Parcel_Machines::ajax_dispatch_order();
		}

		public static function create_stickers() {
			EasyPack_Helper()->ajax_create_stickers();
		}

	}

endif;

